@@ -6,13 +6,15 @@ use warnings;
 
 =head1 NAME
 
+ACME::ltharris - The great new ACME::ltharris!
+
 =head1 VERSION
 
-Version 0.03_01
+Version 0.01
 
 =cut
 
-our $VERSION = '0.03_01'
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
